# SNaP OneDrive Report Aggregator
Utility for ModelTB.org team. Aggregates SNaP reports to a single file.

## Prerequisites
1. Gain access to the following OneDrive folders: TODO
2. Install [OneDrive](https://www.microsoft.com/en-us/microsoft-365/onedrive/download)
3. Install [Python](https://www.python.org/downloads/)

## Installation
1. Ensure that all prerequisites are complete.
2. Open [Terminal (Mac)](https://www.howtogeek.com/682770/how-to-open-the-terminal-on-a-mac/) / [Command Prompt (Windows)](https://www.howtogeek.com/235101/10-ways-to-open-the-command-prompt-in-windows-10/)
3. Enter command: `python -m pip install pipx`
4. Enter command: `python -m pipx ensurepath`
5. Restart Terminal / Command Prompt
6. Enter command: `pipx install snap-tam`

## Running
1. Open Terminal / Command Prompt
2. Enter command: `snap-tam`

## Configuration
When running for the first time, you will be asked to enter the path to your OneDrive installation. What you enter will be stored in the config file.

You can also edit the config file in order to update any changed or incorrectly entered information. Additional options for further customization are also available.

Config file w/ default values:
```json
{
  "onedrive_dir_path": "",
  "input_dir_regexp": [
    "SNAP_TAM_[0-9]{3}",
    "SNAP_TAM_Interviewer"
  ],
  "worksheet_name": "Data Entry Log",
  "duration_colnames": [
    "Duration",
    "Total Interaction Duration"
  ],
  "output_dirname": "SNAP_TAM_Aggregated",
  "print_progress": false
}
```

